@@ -162,14 +162,28 @@ void suspend(){
      QDBusMessage response;
 
      if(lockMyScreen){
-       if(!QProcess::startDetached("gnome-screensaver-command -l"))
-         if(verbose) qWarning() << "W: gnome-screensaver-command -l didn't work";
-       if(!QProcess::startDetached("qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock"))
-         if(verbose) qWarning() << "W: qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock didn't work";
-       if(!QProcess::startDetached("dcop kdesktop KScreensaverIface lock"))
-         if(verbose) qWarning() << "W: dcop kdesktop KScreensaverIface lock didn't work";
-       if(!QProcess::startDetached("xscreensaver-command -lock"))
-         if(verbose) qWarning() << "W: xscreensaver-command -lock didn't work";
+       bool lock_works = false;
+
+       QDBusInterface screenlock("org.gnome.ScreenSaver",
+         "/org/gnome/ScreenSaver", "org.gnome.ScreenSaver",
+         QDBusConnection::systemBus());
+       response = screenlock.call("Lock");
+       if(response.type() == QDBusMessage::ErrorMessage){
+         if(verbose)
+           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+       }
+       else
+         lock_works = true;
+       if(!lock_works){
+         if(!QProcess::startDetached("gnome-screensaver-command -l"))
+           if(verbose) qWarning() << "W: gnome-screensaver-command -l didn't work";
+         if(!QProcess::startDetached("qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock"))
+           if(verbose) qWarning() << "W: qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock didn't work";
+         if(!QProcess::startDetached("dcop kdesktop KScreensaverIface lock"))
+           if(verbose) qWarning() << "W: dcop kdesktop KScreensaverIface lock didn't work";
+         if(!QProcess::startDetached("xscreensaver-command -lock"))
+           if(verbose) qWarning() << "W: xscreensaver-command -lock didn't work";
+       }
      }
 
      gnome_power1 = QProcess::startDetached("gnome-power-cmd.sh suspend");
@@ -228,14 +242,28 @@ void hibernate(){
      QDBusMessage response;
 
      if(lockMyScreen){
-       if(!QProcess::startDetached("gnome-screensaver-command -l"))
-         if(verbose) qWarning() << "W: gnome-screensaver-command -l didn't work";
-       if(!QProcess::startDetached("qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock"))
-         if(verbose) qWarning() << "W: qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock didn't work";
-       if(!QProcess::startDetached("dcop kdesktop KScreensaverIface lock"))
-         if(verbose) qWarning() << "W: dcop kdesktop KScreensaverIface lock didn't work";
-       if(!QProcess::startDetached("xscreensaver-command -lock"))
-         if(verbose) qWarning() << "W: xscreensaver-command -lock didn't work";
+       bool lock_works = false;
+
+       QDBusInterface screenlock("org.gnome.ScreenSaver",
+         "/org/gnome/ScreenSaver", "org.gnome.ScreenSaver",
+         QDBusConnection::systemBus());
+       response = screenlock.call("Lock");
+       if(response.type() == QDBusMessage::ErrorMessage){
+         if(verbose)
+           qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
+       }
+       else
+         lock_works = true;
+       if(!lock_works){
+         if(!QProcess::startDetached("gnome-screensaver-command -l"))
+           if(verbose) qWarning() << "W: gnome-screensaver-command -l didn't work";
+         if(!QProcess::startDetached("qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock"))
+           if(verbose) qWarning() << "W: qdbus org.freedesktop.ScreenSaver /ScreenSaver Lock didn't work";
+         if(!QProcess::startDetached("dcop kdesktop KScreensaverIface lock"))
+           if(verbose) qWarning() << "W: dcop kdesktop KScreensaverIface lock didn't work";
+         if(!QProcess::startDetached("xscreensaver-command -lock"))
+           if(verbose) qWarning() << "W: xscreensaver-command -lock didn't work";
+       }
      }
 
      gnome_power1 = QProcess::startDetached("gnome-power-cmd.sh hibernate");
@@ -273,6 +301,7 @@ void hibernate(){
      if(!upower && !hal && !gnome_power1 && !gnome_power2){
        QDBusInterface powermanagement("org.freedesktop.DeviceKit.Power", "/org/freedesktop/DeviceKit/Power",
          "org.freedesktop.DeviceKit.Power", QDBusConnection::systemBus());
+       response = powermanagement.call("Hibernate");
        if(response.type() == QDBusMessage::ErrorMessage){
          if(verbose)
            qWarning() << "W: " << response.errorName() << ":" << response.errorMessage();
